[Libreoffice-commits] core.git: sw/source

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Sat Aug 29 09:30:40 UTC 2020


 sw/source/filter/ww8/ww8scan.cxx |    4 ++--
 sw/source/filter/ww8/ww8scan.hxx |    4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 2f297f4680a3b523005f4d4f762e195ba5f8912e
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Fri Aug 28 12:11:11 2020 +0200
Commit:     Noel Grandin <noel.grandin at collabora.co.uk>
CommitDate: Sat Aug 29 11:29:43 2020 +0200

    Fix typo in code
    
    It passed "make check" on Linux
    
    Change-Id: I63ce9d46922b1a7a1f90308d2eec46b22ff925df
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101595
    Tested-by: Jenkins
    Reviewed-by: Noel Grandin <noel.grandin at collabora.co.uk>

diff --git a/sw/source/filter/ww8/ww8scan.cxx b/sw/source/filter/ww8/ww8scan.cxx
index 4bb690199826..3efefc1067e5 100644
--- a/sw/source/filter/ww8/ww8scan.cxx
+++ b/sw/source/filter/ww8/ww8scan.cxx
@@ -7753,7 +7753,7 @@ WW8Dop::WW8Dop(SvStream& rSt, sal_Int16 nFib, sal_Int32 nPos, sal_uInt32 nSize):
 
             nfcFootnoteRef = Get_Short( pData );      // 492 0x1ec
             nfcEdnRef = Get_Short( pData );      // 494 0x1ee
-            hpsZoonFontPag = Get_Short( pData ); // 496 0x1f0
+            hpsZoomFontPag = Get_Short( pData ); // 496 0x1f0
             dywDispPag = Get_Short( pData );     // 498 0x1f2
 
             if (nRead >= 516)
@@ -8189,7 +8189,7 @@ void WW8Dop::Write(SvStream& rStrm, WW8Fib& rFib) const
 
         Set_UInt16( pData, nfcFootnoteRef );                // 492 0x1ec
         Set_UInt16( pData, nfcEdnRef );                // 494 0x1ee
-        Set_UInt16( pData, hpsZoonFontPag );           // 496 0x1f0
+        Set_UInt16( pData, hpsZoomFontPag );           // 496 0x1f0
         Set_UInt16( pData, dywDispPag );               // 498 0x1f2
 
         //500 -> 508, Appear to be repeated here in 2000+
diff --git a/sw/source/filter/ww8/ww8scan.hxx b/sw/source/filter/ww8/ww8scan.hxx
index d2b32ae80df1..2e42d33dc19b 100644
--- a/sw/source/filter/ww8/ww8scan.hxx
+++ b/sw/source/filter/ww8/ww8scan.hxx
@@ -1758,7 +1758,7 @@ public:
      bool       fIncludeHeader : 1 /*= false*/;    // Place header inside page border
      bool       fIncludeFooter : 1 /*= false*/;    // Place footer inside page border
      bool       fForcePageSizePag : 1 /*= false*/; // Are we in online view
-     bool       fMinFontSizePag : 1 /*= false*/;   // Are we auto-promoting fonts to >= hpsZoonFontPag?
+     bool       fMinFontSizePag : 1 /*= false*/;   // Are we auto-promoting fonts to >= hpsZoomFontPag?
      bool       fHaveVersions : 1 /*= false*/;     // versioning is turned on
      bool       fAutoVersion : 1 /*= false*/;      // autoversioning is enabled
     sal_uInt16 : 14;                  // reserved
@@ -1772,7 +1772,7 @@ public:
     // Skip 4 Bytes here
     sal_Int16 nfcFootnoteRef = 0;
     sal_Int16 nfcEdnRef = 0;
-    sal_Int16 hpsZoonFontPag = 0;
+    sal_Int16 hpsZoomFontPag = 0;
     sal_Int16 dywDispPag = 0;
 
      bool       fCompatibilityOptions_Unknown2_1 : 1 /*= false*/;  // #i78591#


More information about the Libreoffice-commits mailing list